@@ -304,6 +304,8 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
             return APIResponse(None, status=404, msg=f'请指定post操作类型, 取值范围: {self.post_type_ls}?')
 
     def get_serializer_class(self):
+        request_data = self.get_request_data()
+
         if self.method == 'retrieve':
             ret = self.retrieve_serializer_class or self.serializer_class
         elif self.method == 'list':
@@ -311,7 +313,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         else:
             ret = self.retrieve_serializer_class or self.serializer_class or self.list_serializer_class
 
-        if self.auto_generate_serializer_class and self.serializer_class is None:
+        if (self.auto_generate_serializer_class and ret is None) or request_data.get('base_fields'):
             ret = get_base_serializer(self.queryset, base_fields=self.get_base_fields())
 
         # --- 仅获取distinct之后的字段
@@ -396,6 +398,9 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         # --- 得到list方法的queryset
         self.queryset = self.get_list_queryset()
 
+        if not isinstance(self.queryset, QuerySet):
+            self.queryset = self.queryset.objects.all()
+
         # --- 根据ordering参数, 获得排序后的queryset
         self.queryset = self.get_ordered_queryset()
 
@@ -614,6 +619,18 @@ def get_base_queryset(obj) -> QuerySet:
     return ret
 
 
+def conv_to_queryset(obj) -> QuerySet:
+    """
+    强制转换为QuerySet
+    """
+    if not isinstance(obj, QuerySet):
+        ret = get_base_model(obj)
+        ret = ret.objects.all()
+    else:
+        ret = obj
+    return ret
+
+
 def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16, context=None):
     """
     * 手动分页函数
